Ext.ns('Pyrone.tr');

Pyrone.tr = {
'AJAX_REQUEST_ERROR': 'AJAX request error',
'ARTICLE_NOT_SAVED': 'Article has not been saved due to error.',
'ARTICLE_SAVED': 'Article has been saved.',
'BACKUP_RESTORE_COMPLETE': 'Backup restore complete',
'COMMENT_BODY_IS_REQUIRED': 'Comment body is required',
'COMMENT_DISPLAY_NAME_IS_REQUIRED': 'Display name is required',
'COMMENT_IS_WAITING_FOR_APPROVAL': 'Comment is waiting for approval',
'FIELD_IS_REQUIRED': 'Field is required',
'FIELD_MUST_BE_ALPHA_NUM': 'Field must contain alphanumeric characters',
'FILE_NAME_ALREADY_EXISTS_IN_THE_STORAGE': 'File with the same name already exists in the storage',
'PASSWORDS_DONT_MATCH': 'Passwords don\'t match',
'SELECT_FILE_TO_UPLOAD': 'Select file to upload',
'SELECT_ITEMS_FIRST': 'Select items first',
'SETTINGS_SAVED': 'Settings have been saved',
'TWITTER_AUTH_IS_NOT_WORKING': 'Twitter authentication is not working',
'YOUR_PROFILE_HAS_BEEN_UPDATED': 'Your profile has been updated'
};
